@@ -64,44 +64,89 @@ namespace Cowbell.Base
 		}
 
 		/* private methods */
-		[DllImport("libintl")]
-		private static extern IntPtr bindtextdomain (IntPtr domainname, IntPtr dirname);
+		[DllImport("intl", EntryPoint="bindtextdomain")]
+		private static extern IntPtr intl_bindtextdomain (IntPtr domainname, IntPtr dirname);
+
+		[DllImport("libintl", EntryPoint="bindtextdomain")]
+		private static extern IntPtr libintl_bindtextdomain (IntPtr domainname, IntPtr dirname);
 
 		private static void BindTextDomain (IntPtr domainname, IntPtr dirname)
 		{
-			bindtextdomain (domainname, dirname);
+			// XXX: Hack around the libintl -> intl change for mono 1.1.13.
+
+			try {
+				intl_bindtextdomain (domainname, dirname);
+			} catch (DllNotFoundException e) {
+				libintl_bindtextdomain (domainname, dirname);
+			}
 		}
 
-		[DllImport("libintl")]
-		private static extern IntPtr bind_textdomain_codeset (IntPtr domainname, IntPtr codeset);
+		[DllImport("intl", EntryPoint="bind_textdomain_codeset")]
+		private static extern IntPtr intl_bind_textdomain_codeset (IntPtr domainname, IntPtr codeset);
+
+		[DllImport("libintl", EntryPoint="bind_textdomain_codeset")]
+		private static extern IntPtr libintl_bind_textdomain_codeset (IntPtr domainname, IntPtr codeset);
 
 		private static void BindTextDomainCodeset (IntPtr domainname, IntPtr codeset)
 		{
-			bind_textdomain_codeset (domainname, codeset);
+			try {
+				intl_bind_textdomain_codeset (domainname, codeset);
+			} catch (DllNotFoundException e) {
+				libintl_bind_textdomain_codeset (domainname, codeset);
+			}
 		}
 
-		[DllImport("libintl")]
-		private static extern IntPtr textdomain (IntPtr domainname);
+		[DllImport("intl", EntryPoint="textdomain")]
+		private static extern IntPtr intl_textdomain (IntPtr domainname);
+
+		[DllImport("libintl", EntryPoint="textdomain")]
+		private static extern IntPtr libintl_textdomain (IntPtr domainname);
 
 		private static void TextDomain (IntPtr domainname)
 		{
-			textdomain (domainname);
+			try {
+				intl_textdomain (domainname);
+			} catch (DllNotFoundException e) {
+				libintl_textdomain (domainname);
+			}
 		}
 
-		[DllImport("libintl")]
-		private static extern IntPtr gettext (IntPtr instring);
+		[DllImport("intl", EntryPoint="gettext")]
+		private static extern IntPtr intl_gettext (IntPtr instring);
+
+		[DllImport("libintl", EntryPoint="gettext")]
+		private static extern IntPtr libintl_gettext (IntPtr instring);
 
 		private static IntPtr Gettext (IntPtr instring)
 		{
-			return gettext (instring);
+			IntPtr ptr = IntPtr.Zero;
+
+			try {
+				ptr = intl_gettext (instring);
+			} catch (DllNotFoundException e) {
+				ptr = libintl_gettext (instring);
+			}
+
+			return ptr;
 		}
 
-		[DllImport("libintl")]
-		private static extern IntPtr ngettext (IntPtr singular, IntPtr plural, Int32 n);
+		[DllImport("intl", EntryPoint="ngettext")]
+		private static extern IntPtr intl_ngettext (IntPtr singular, IntPtr plural, Int32 n);
+
+		[DllImport("libintl", EntryPoint="ngettext")]
+		private static extern IntPtr libintl_ngettext (IntPtr singular, IntPtr plural, Int32 n);
 
 		private static IntPtr NGettext (IntPtr s, IntPtr p, Int32 n)
 		{
-			return ngettext (s, p, n);
+			IntPtr ptr = IntPtr.Zero;
+
+			try {
+				ptr = intl_ngettext (s, p, n);
+			} catch (DllNotFoundException e) {
+				ptr = libintl_ngettext (s, p, n);
+			}
+			
+			return ptr;
 		}
 	}
 }
