@@ -30,7 +30,7 @@ namespace Cowbell.Base
 		/* public methods */
 		public static bool Import (string filename)
 		{
-			if (filename == "") {
+			if (filename == String.Empty) {
 				return false;
 			}	
 
@@ -49,7 +49,7 @@ namespace Cowbell.Base
 
 			foreach (string uri in uris)
 			{
-				string filename = GetLocalPathFromUri (uri);
+				string filename = SafeUri.UriToFilename (uri);
 				Song s = GetSongFromFile (filename);
 
 				if (s == null) {
@@ -163,7 +163,7 @@ namespace Cowbell.Base
 				// Feed it right into the song class
 				s = new Song (filename);
 
-				if (s.Title == "") {
+				if (s.Title == String.Empty) {
 					s.PathToTitle (filename);
 				}
 			} catch (Exception e) {
@@ -194,10 +194,11 @@ namespace Cowbell.Base
 				try {
 					// Feed it right into the song class
 					songs = new Song[1];
-					songs[0] = new Song (filename);
+					songs[0] = GetSongFromFile (filename);
 
-					if (songs[0].Title == "")
+					if (songs[0].Title == String.Empty) {
 						songs[0].PathToTitle (filename);
+					}
 				} catch (Exception e) {
 					songs = null;
 				}
@@ -206,17 +207,6 @@ namespace Cowbell.Base
 			return songs;
 		}
 
-		public static string GetLocalPathFromUri (string path)
-		{
-			Uri uri = new Uri (path);
-
-			if (uri.Scheme == "file") {
-				return uri.LocalPath;
-			}
-
-			return null;
-		}
-
 		public static void ExportPlaylist (string path)
 		{
 			if (Runtime.Preferences.PlaylistType == "pls") {
