@@ -23,14 +23,12 @@ using System;
 
 namespace Cowbell.Base
 {
-	public delegate void MetadataProxyHeartbeatHandler (string text);
-
 	public interface IMetadataProxy
 	{
-		event MetadataProxyHeartbeatHandler Heartbeat;
-		event EventHandler ConnectionFailed;
-		event EventHandler ConnectionRejected;
-		event EventHandler Completed;
+		event StringHandler Heartbeat;
+		event StringHandler ConnectionFailed;
+		event StringHandler ConnectionRejected;
+		event VoidHandler Completed;
 
 		void Import ();
 	}
