@@ -51,8 +51,7 @@ namespace Cowbell.Gui
 			                    + "Bailey Kong <bailey@tgpsolutions.com> (ja)";
 			Website = "http://www.more-cowbell.org";
 			WebsiteLabel = "http://www.more-cowbell.org";
-
-			Logo = new Gdk.Pixbuf (null, "cowbell-48.png");
+			LogoIconName = "cowbell";
 		}
 
 		/* private fields */
