@@ -34,6 +34,13 @@ using Cowbell.Base;
 
 namespace Cowbell
 {
+	/*
+	 * Sean Connery: Well, the game is afoot. I'll take anal bum cover for 7,000.
+	 *  Alex Trebek: That's An album cover, not anal bum cover.
+	 * Sean Connery: I can read, Trebek. That says Anal bum cover. I've
+	 *               spent five years of my life trying to invent an anal
+	 *               bum cover, failing to do so is my greatest regret. 
+	 */
 	public class AlbumCoverImage : EventBox
 	{
 		/* public methods */
@@ -439,13 +446,13 @@ namespace Cowbell
 			switch (args.Info) {
 			case (uint)TargetType.Uri:
 				tokens = Regex.Split (selectiondata, "\n");
-				Uri uri = new Uri (tokens[0]);
+				SafeUri uri = new SafeUri (tokens[0]);
 				
 				if (uri.Scheme != "http")
 					break;
 
 				try {
-					original = GetCoverFromUrl (uri.AbsoluteUri);
+					original = GetCoverFromUrl (SafeUri.UriToFilename (uri));
 					UserPixbuf = true;
 					success = true;
 				} catch (Exception e) {
@@ -457,7 +464,7 @@ namespace Cowbell
 			
 			case (uint)TargetType.UriList:
 				tokens = Regex.Split (selectiondata, "\r\n");		
-				path = Filesystem.GetLocalPathFromUri (tokens[0]);
+				path = SafeUri.UriToFilename (tokens[0]);
 
 				if (path == null)
 					break;
