@@ -32,12 +32,10 @@ namespace Cowbell.Gui
 		{
 			xml = new Glade.XML (null, resource, "dialog", null);
 			xml.BindFields (this);
-			
-			if (icon == null) {
-				icon = new Gdk.Pixbuf (null, "cowbell.png");
-			}
 
 			dialog = ((Dialog)xml["dialog"]);
+
+			dialog.IconName = "cowbell";
 		}
 
 		public int Run ()
@@ -54,9 +52,6 @@ namespace Cowbell.Gui
 		protected Glade.XML xml;
 		protected Dialog dialog;
 
-		/* private properties */
-		private static Gdk.Pixbuf icon;
-
 		/* private methods */
 		static GladeDialog ()
 		{
