@@ -33,11 +33,7 @@ namespace Cowbell.Gui
 			xml = new Glade.XML (null, resource, name, null);
 			xml.BindFields (this);
 			
-			if (icon == null) {
-				icon = new Gdk.Pixbuf (null, "cowbell.png");
-			}
-
-			((Window)xml["window"]).Icon = icon;
+			((Window)xml["window"]).IconName = "cowbell";
 		}
 
 		public void Show ()
@@ -48,9 +44,6 @@ namespace Cowbell.Gui
 		/* protected properties */
 		protected Glade.XML xml;
 
-		/* private properties */
-		private static Gdk.Pixbuf icon;
-
 		/* private methods */
 		static GladeWindow ()
 		{
