@@ -107,9 +107,7 @@ namespace Cowbell.Gui
 
 		private void Thaw ()
 		{
-			/* FIXME: Revert isn't implemented yet
 			revert.Sensitive = true;
-			*/
 			clear_list.Sensitive = true;
 			guess_song_information.Sensitive = true;
 			YearEntry.Sensitive = true;
@@ -231,6 +229,14 @@ namespace Cowbell.Gui
 				Thaw ();
 			}
 
+			if (Runtime.Database.Count > 25) {
+				/* NOTE: This isn't Catalog.GetPluralString
+				 * because we're guaranteed to have more than
+				 * 25 songs.  If this is a problem in your
+				 * language, let me know. */
+				Runtime.Gui.ShowError (String.Format (Catalog.GetString ("You have just imported {0} songs, generally more than one album worth of music.\n\nCowbell is intended for tagging just one album at a time, and will not work effectively if given more than one album.  To tag multiple albums at a time, Cowbell has a batch tagging mode, enabled by passing \"--batch\" on the console.\n\nIf you are only trying to tag one album, you can safely ignore this message."), Runtime.Database.Count));
+			}
+
 			cover.Clear ();
 			OnCoverImageUpdateTimeout ();
 		}
@@ -261,6 +267,8 @@ namespace Cowbell.Gui
 		
 		private void OnFileRevertActivate (object o, EventArgs args)
 		{
+			Runtime.Database.RevertAll ();
+			Runtime.Dirty = false;
 		}
 
 		private void OnGuessSongInformationActivate (object o, EventArgs args)
@@ -273,6 +281,11 @@ namespace Cowbell.Gui
 		{
 			PreferencesWindow pw = new PreferencesWindow ();
 			pw.Show ();
+			
+			/* just sensitize the save icon, but don't set the app
+			 * dirty (because this would make you have to save
+			 * before you exit) */
+			save.Sensitive = true;
 		}
 
 		private void OnEditClearListActivate (object o, EventArgs args)
