@@ -325,7 +325,7 @@ namespace Cowbell.Gui
 					}
 
                                         try {
-                                                string path = Filesystem.GetLocalPathFromUri (token);
+                                                string path = SafeUri.UriToFilename (token);
                                                 foreach (Song s in Filesystem.GetSongsFromFilesystem (path))
 						{
 							Runtime.Database.Add (s);
